=======
Credits
=======

Development Lead
----------------

* Morten Niklas Gjerding <mortengjerding@gmail.com>

Contributors
------------

CAMD
* Thorbjørn Skovhus
* Asbjørn Rasmussen
* Luca Vanucci
* Hadeel Moustafa
* Fabian Felix Bertoldo
* Anders Christian-Riis Jensen
* Alireza Taghizadeh
* Simone Manti
* Jens-Jørgen Mortensen
* ... (contact me if you or someone you know has been forgotten)
